# Changelog

## [stormi-v0.6.0](https://github.com/pinellolab/stormi/compare/stormi-v0.5.0...stormi-v0.6.0) (2025-06-30)

### Features

* **models:** Added new models to init file ([790a9b0](https://github.com/pinellolab/stormi/commit/790a9b0b74d0a7fc9655d7087f5fa22536c99e5b))
* **models:** Model with 2 layer neural net for each path and continuous weights for each path in each cell. ([a348853](https://github.com/pinellolab/stormi/commit/a348853a3580323255f2657a1c4623ee602d3a54))
* **models:** Model with seperate 2layer neural net for transcription rate in each path and categorical path assignment compatible with enumeration based inference. ([2ca6f66](https://github.com/pinellolab/stormi/commit/2ca6f66824b80eea64d0d9c8cd59c20b76db1c0d))
* **models:** model with simple jax euler integration and two layer neural net. ([3412af2](https://github.com/pinellolab/stormi/commit/3412af27bd12f79232592f8229bde821c9a8c29a))
* **models:** Updated readme to describe all current models. ([2b41dcd](https://github.com/pinellolab/stormi/commit/2b41dcdfd145f381b879265f6ac46f9f3b21b29a))
* **pyproject.toml:** Added funsor for enumeration based inference. ([868f81f](https://github.com/pinellolab/stormi/commit/868f81fb4c006dbdb1c809e6e063a975edde0549))

### Bug Fixes

* **pyproject:** add funsor to pixi deps ([0658341](https://github.com/pinellolab/stormi/commit/0658341f0d7dfc84b006b9bb39e43d92215f149e))
